===========
User manual
===========

.. toctree::
   :maxdepth: 2

   installation.rst
   quickstart.rst
   tutorial.rst
   mesh.rst
   hydrostatics.rst
   problem_setup.rst
   resolution.rst
   outputs.rst
   post_pro.rst
   conventions.rst
   cookbook.rst
